PALM-meteo: palmmeteo_stdplugins.icon Namespace Reference

PALM-meteo

Classes | Functions | Variables
palmmeteo_stdplugins.icon Namespace Reference

## Classes
class | IconPlugin

## Functions
def | lpad (var)
def | log_dstat_on (desc, delta)
def | log_dstat_off (desc, delta)
def | get_3dvar (f, varname)
def | assign_time (coll, key, value)

## Variables
| barom_pres = PalmPhysics.barom_lapse0_pres
| barom_gp = PalmPhysics.barom_lapse0_gp
| g = PalmPhysics.g

## Function Documentation

## ◆ assign_time()

def palmmeteo_stdplugins.icon.assign_time | ( |  | coll,
|  |  | key,
|  |  | value
| ) |  |

    Assigns value = coll[key] only if that was previously None,
    otherwise raises an error.

## ◆ get_3dvar()

def palmmeteo_stdplugins.icon.get_3dvar | ( |  | f,
|  |  | varname
| ) |  |

## ◆ log_dstat_off()

def palmmeteo_stdplugins.icon.log_dstat_off | ( |  | desc,
|  |  | delta
| ) |  |

    Do nothing (log disabled)

## ◆ log_dstat_on()

def palmmeteo_stdplugins.icon.log_dstat_on | ( |  | desc,
|  |  | delta
| ) |  |

    Calculate and log delta statistics if enabled.

## ◆ lpad()

def palmmeteo_stdplugins.icon.lpad | ( |  | var | ) |

    Pad variable in first dimension by repeating lowest layer twice

## Variable Documentation

## ◆ barom_gp

palmmeteo_stdplugins.icon.barom_gp = PalmPhysics.barom_lapse0_gp

## ◆ barom_pres

palmmeteo_stdplugins.icon.barom_pres = PalmPhysics.barom_lapse0_pres

## ◆ g

palmmeteo_stdplugins.icon.g = PalmPhysics.g